==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/ja.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "ライトボックスGALLARYパラメータを管理します");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "ギャラリーを管理します");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "フルサイズイメージの幅");
define('MANAGE_GALLERY_FULL_HEIGHT', "フルサイズイメージの高さ");
define('MANAGE_GALLERY_THUMB_WIDTH', "サムネイル画像の幅");
define('MANAGE_GALLERY_THUMB_HEIGHT', "サムネイル画像の高さ");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "親指のアスペクト比を保持");
define('MANAGE_GALLERY_SHOW_TITLES', "表示タイトル");
define('MANAGE_GALLERY_DISABLE_SORT', "無効にソート");
define('MANAGE_GALLERY_DELETE_IMAGE', "画像を削除");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "オーダーソート保存");
define('MANAGE_GALLERY_PUBLISH_MSG', "公開するには、「アップデート」をクリックしてください<br />あなたのアップロードした画像。");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "すべての画像はリサイズされており、設定が保存されています。");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "エラー画像のサイズを変更するか、設定の保存がありました。");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "あなたのイメージ（複数可）がアップロードされています。");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "あなたのイメージ（複数可）をアップロード中にエラーが発生しました。");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "アップロードしようとしているファイルは画像ではありません。");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "アップロードしようとしているファイルが大きすぎます。");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "タイトルが保存されました。");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "あなたは、画像を削除してもよろしいです");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "？");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "画像は削除されました。");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "イメージの削除中にエラーが発生しました。");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "パラメータを保存し、画像をリサイズしています。お待ちください...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "アップロードは、しばらくお待ちください...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ソート順序が保存されていません。あなたはソート順を保存しますか？");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "画像の並べ替え順序が保存されました。");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "画像の並べ替えを保存中にエラーが発生しました。");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ja.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "ライトボックスGALLARYパラメータを管理します");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "ギャラリーを管理します");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "フルサイズイメージの幅");
define('MANAGE_GALLERY_FULL_HEIGHT', "フルサイズイメージの高さ");
define('MANAGE_GALLERY_THUMB_WIDTH', "サムネイル画像の幅");
define('MANAGE_GALLERY_THUMB_HEIGHT', "サムネイル画像の高さ");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "親指のアスペクト比を保持");
define('MANAGE_GALLERY_SHOW_TITLES', "表示タイトル");
define('MANAGE_GALLERY_DISABLE_SORT', "無効にソート");
define('MANAGE_GALLERY_DELETE_IMAGE', "画像を削除");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "オーダーソート保存");
define('MANAGE_GALLERY_PUBLISH_MSG', "公開するには、「アップデート」をクリックしてください<br />あなたのアップロードした画像。");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "すべての画像はリサイズされており、設定が保存されています。");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "エラー画像のサイズを変更するか、設定の保存がありました。");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "あなたのイメージ（複数可）がアップロードされています。");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "あなたのイメージ（複数可）をアップロード中にエラーが発生しました。");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "アップロードしようとしているファイルは画像ではありません。");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "アップロードしようとしているファイルが大きすぎます。");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "タイトルが保存されました。");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "あなたは、画像を削除してもよろしいです");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "？");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "画像は削除されました。");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "イメージの削除中にエラーが発生しました。");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "パラメータを保存し、画像をリサイズしています。お待ちください...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "アップロードは、しばらくお待ちください...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ソート順序が保存されていません。あなたはソート順を保存しますか？");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "画像の並べ替え順序が保存されました。");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "画像の並べ替えを保存中にエラーが発生しました。");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "アップロードしようとしているファイルは、PHPの「upload_max_filesize」または「post_max_size」設定よりも大きくなっています。システム管理者に連絡して、これらの制限を増やしてください。");
?>
